using System.Windows.Forms;
using Microsoft.Win32;

namespace FileTypeAssociation
{
    public partial class Main : Form
    {
        #region constructor

        public Main()
        {
            InitializeComponent();
        }

        #endregion
        #region methods

        private void btnAdd_Click(object sender, System.EventArgs e)
        {
            // create the program browser
            ProgramBrowser pb = new ProgramBrowser(); 

            // if it comes back with an ok result
            // add the program to the list
            if (pb.ShowDialog(this) == DialogResult.OK) 
            {
                // if the Program isn't already in the list
                // then add it
                if (lst.Items.IndexOf(pb.Program) == -1)
                {
                    lst.Items.Add(pb.Program);
                }
            }
            // release the resources of the program browser because we no longer need it
            pb.Dispose();
        }

        private void btnRemove_Click(object sender, System.EventArgs e)
        {
            // find out the index of the last item in the list by subtracting 1 from the count
            // (if there's 1 item, it'll be in index or spot 0)
            int last = lst.Items.Count - 1;
            // if the last is greater than - 1 ( the list has items in it)
            // remove the item in the last index
            if (last > -1)
            {
                lst.Items.RemoveAt(last);
            }
        }

        private void btnSave_Click(object sender, System.EventArgs e)
        {
            #region error checking

            string _extension = txtExtension.Text.Trim();
            string _fileType = txtFileType.Text.Trim();
            // if the trimmed(remove spaces at the front and back) text in extension textbox is null or empty
            //     display a message box and return(don't continue in the sub
            if(string.IsNullOrEmpty(_extension))
            {
                MessageBox.Show(this, "You must fill in an extension", 
                            "Extension", MessageBoxButtons.OK, MessageBoxIcon.Hand); return;
            }
            // if the trimmed file type text is null or empty
            //     display a message box and return
            if (string.IsNullOrEmpty(_fileType))
            {
                MessageBox.Show(this, "You must fill in an extension",
                            "Extension", MessageBoxButtons.OK, MessageBoxIcon.Hand); return;
            }
            // if the list doesn't have any items in it
            //     display a message box telling the user they must add applications to open the files with
            if (lst.Items.Count < 1)
            {
                MessageBox.Show(this, "You must add programs to use when opening the file extension.",
                            "Add Programs", MessageBoxButtons.OK, MessageBoxIcon.Hand); return;
            }
            #endregion
            #region set up the registry keys

            // Create a registry key for files with our extension
            RegistryKey extension =  Registry.ClassesRoot.CreateSubKey(_extension);

            // Set the default value to the file type name, to point it to the key we're gonna make
            extension.SetValue("", _fileType, RegistryValueKind.String);

            // Create the key for our file type
            RegistryKey fileType = Registry.ClassesRoot.CreateSubKey(_fileType);
            fileType.SetValue("", "Halo Map File", RegistryValueKind.String);

            // Create the shell key, we'll put our open commands in here
            RegistryKey shell = fileType.CreateSubKey("shell");
            
            // Set the open command, this is the double click command
            RegistryKey current = shell.CreateSubKey("open");

            // cast the items we get out of the list to our program class
            ProgramToUse program = (lst.Items[0] as ProgramToUse);

            // create a command key for opening it with
            current = current.CreateSubKey("command");

            //set the default value of the command key
            // %1 is the file that was double clicked and we send that to the path of the program
            current.SetValue("", string.Format("\"{0}\" \"%1\"", program.Path));
            // for each program in the list
            //    set up a key for it inside the file type key's shell key
            for (int i = 1; i < lst.Items.Count; i++)
            {
                // same as above for setting programs up, except we use open with, 
                // because you can't have multiple open commands
                program = (lst.Items[i] as ProgramToUse);
                current = shell.CreateSubKey(string.Format("Open with {0}", program.Name));
                current = current.CreateSubKey("command");
                current.SetValue("", string.Format("\"{0}\" \"%1\"", program.Path));
            }

            #endregion
            MessageBox.Show(this,"Done");
        }

        #endregion
    }
}