using System;
using System.Drawing;
using System.Windows.Forms;

namespace FileTypeAssociation
{
    public partial class ProgramBrowser : Form
    {
        #region fields

        private ProgramToUse _program;

        #endregion
        #region accessors

        /// <summary>
        /// Gets the ProgramBrowsers ProgramToUse
        /// </summary>
        public ProgramToUse Program
        {
            get { return _program; }
        }

        #endregion
        #region constructor

        public ProgramBrowser()
        {
            InitializeComponent();
        }

        #endregion
        #region methods

        private void btnBrowse_Click(object sender, EventArgs e)
        {
            using (OpenFileDialog ofd = new OpenFileDialog())
            {
                // Set the Open File Dialog's properties
                ofd.CheckFileExists = true;
                ofd.Filter = "Applications(*.exe)|*.exe";
                ofd.Multiselect = false;
                ofd.Title = "Open";
                // ShowDialog returns a dialog result
                // If the dialog result isn't cancel
                //   change the path's text to the ofd's filename
                if (ofd.ShowDialog(this) != DialogResult.Cancel)
                {
                    txtPath.Text = ofd.FileName;
                }
            }
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            string name = txtName.Text.Trim();
            string path = txtPath.Text.Trim();

            #region error checking

            if (string.IsNullOrEmpty(name))
            {
                MessageBox.Show("You must fill in the application name before proceeding.",
                    "Name", MessageBoxButtons.OK, MessageBoxIcon.Hand); return;
            }
            if (string.IsNullOrEmpty(path))
            {
                MessageBox.Show("You must fill in the path before proceeding.",
                    "Path", MessageBoxButtons.OK, MessageBoxIcon.Hand); return;
            }

            #endregion

            _program = new ProgramToUse(name, path);
            DialogResult = DialogResult.OK;
        }

        #endregion
    }
}